summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteaccount.h')
-rw-r--r--kopete/libkopete/kopeteaccount.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kopete/libkopete/kopeteaccount.h b/kopete/libkopete/kopeteaccount.h
index 854890af..1cf045d2 100644
--- a/kopete/libkopete/kopeteaccount.h
+++ b/kopete/libkopete/kopeteaccount.h
@@ -28,7 +28,7 @@
class TQDomNode;
class KActionMenu;
-class KConfigGroup;
+class TDEConfigGroup;
namespace Kopete
{
@@ -55,7 +55,7 @@ class BlackLister;
* the user tied to this account. You must create this contact in the contructor of your
* account and pass it to @ref setMyself().
*
* All account data is saved to @ref KConfig. This includes the accountId, the autoconnect flag and
* the color. You can save more data using @ref configGroup()
*
* When you create a new account, you have to register it with the account manager by calling
@@ -307,14 +307,14 @@ public:
bool isAway() const;
/**
* Return the @ref KConfigGroup used to write and read special properties
*
* "Protocol", "AccountId" , "Color", "AutoConnect", "Priority", "Enabled" , "Icon" are reserved keyword
* already in use in that group.
*
* for compatibility, try to not use key that start with a uppercase
*/
- KConfigGroup *configGroup() const;
+ TDEConfigGroup *configGroup() const;
/**
* @brief Remove the account from the server.
@@ -434,7 +434,7 @@ signals:
private:
/**
* @internal
* Reads the configuration information of the account from KConfig.
*/
void readConfig();
@@ -55,7 +55,7 @@ class BlackLister;
* account and pass it to @ref setMyself().
*
- * All account data is saved to @ref KConfig. This includes the accountId, the autoconnect flag and
+ * All account data is saved to @ref TDEConfig. This includes the accountId, the autoconnect flag and
* the color. You can save more data using @ref configGroup()
*
@@ -307,14 +307,14 @@ public:
bool isAway() const;
/**
- * Return the @ref KConfigGroup used to write and read special properties
+ * Return the @ref TDEConfigGroup used to write and read special properties
*
* "Protocol", "AccountId" , "Color", "AutoConnect", "Priority", "Enabled" , "Icon" are reserved keyword
@@ -434,7 +434,7 @@ signals:
/**
* @internal
- * Reads the configuration information of the account from KConfig.
+ * Reads the configuration information of the account from TDEConfig.
*/
void readConfig();